yakumo.glance.v2.image_member.Manager

Package yakumo :: Package glance :: Package v2 :: Module image_member :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

          object --+
                   |
        base.Manager --+
                       |
         base.SubManager --+
                           |
          object --+       |
                   |       |
        base.Manager --+   |
                       |   |
    base.GlanceV2Manager --+
                           |
     base.GlanceV2SubManager --+
                               |
                              Manager

manager class for image membes on Image V2 API

Nested Classes | [hide private]
| resource_class resource class for image members on Image V2 API

Instance Methods | [hide private]
yakumo.glance.v2.image_member.Resource |
create(self, user=`'``__UNDEF__``'`) Register a member for a image | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.GlanceV2Manager`: `get` Inherited from `base.Manager`: `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``image``'``
| _attr_mapping = ``[``(``'``user``'``,` `'``member_id``'``,` <yakumo.mapper.Resource`...``
| _id_attr = ``'``user``'``
| _json_resources_key = ``'``members``'``
| _url_resource_path = ``'``/v2/images/%s/members``'``
Inherited from `base.GlanceV2Manager` (private): `_has_extra_attr` Inherited from `base.Manager` (private): `_has_detail`, `_hidden_methods`, `_json_resource_key`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, user=`'``__UNDEF__``'`) | source code
Register a member for a image Parameters: `user` (yakumo.user.Resource) - New user (required) Returns: yakumo.glance.v2.image_member.Resource Registered image member Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('user',
        'member_id',
        <yakumo.mapper.Resource object at 0x7f132fe94250>),
       ('image',
        'image_id',
        <yakumo.mapper.Resource object at 0x7f132fe94350>),
       ('schema',
        'schema',
      ...